@@ -3,22 +3,22 @@ import shutil
 import sys
 from pathlib import Path
 
+import cv2 as cv
 import numpy as np
-
 from mmdet.apis import inference_detector, init_detector, show_result_pyplot
 
 
 class Detector:
+    """Instantiate an object detector.
+
+    Args:
+        config_file (str): Config file path.
+        checkpoint_file (str): Checkpoint file path.
+        device (str, optional): Device used for calculating. Defaults to "cuda:0".
+        cfg_options (dict, optional): Options to override some settings. Defaults to None.
+    """
 
     def __init__(self, config_file, checkpoint_file, device="cuda:0", cfg_options=None) -> None:
-        """Instantiate an object detector.
-
-        Args:
-            config_file (str): Config file path.
-            checkpoint_file (str): Checkpoint file path.
-            device (str, optional): Device used for calculating. Defaults to "cuda:0".
-            cfg_options (dict, optional): Options to override some settings. Defaults to None.
-        """
         self.model = init_detector(config_file, checkpoint_file, device, cfg_options)
 
     def test_images(self, images_or_dir, score_thr=0.3, out_dir=None):
@@ -57,18 +57,20 @@ class Detector:
         Args:
             img (str): Image file.
         """
-        bbox_result = inference_detector(self.model, image_path)
+        image = cv.imread(image_path, 1)  # cv.IMREAD_COLOR
+
+        bbox_result = inference_detector(self.model, image)
 
         if out_file is not None:
-            show_result_pyplot(self.model, image_path, bbox_result, score_thr=score_thr, out_file=out_file)
+            show_result_pyplot(self.model, image, bbox_result, score_thr=score_thr, out_file=out_file)
 
-        return bbox_result, image_path
+        height, width = image.shape[:2]
+        return bbox_result, image_path, height, width
 
     def to_file(self, results, txt_file):
         """Format results.
 
-        Such as:
-            filepath,height,width,x1,y1,x2,y2,confidence,label,x1,y1,x2,y2,confidence,label
+        Such as ``filepath,height,width,x1,y1,x2,y2,s,l,x1,y1,x2,y2,s,l``.
 
         Args:
             results (list[tuple]): The results.
@@ -76,7 +78,7 @@ class Detector:
         class_names = self.model.CLASSES
 
         lines = []
-        for bbox_result, image_path in results:
+        for bbox_result, image_path, height, width in results:
             bboxes = np.vstack(bbox_result)
             labels = [
                 np.full(bbox.shape[0], i, dtype=np.int32)
@@ -84,7 +86,7 @@ class Detector:
             ]
             labels = np.concatenate(labels)
 
-            line = [image_path, "0", "0"]
+            line = [f"{image_path},{height},{width}"]
             for bbox, label in zip(bboxes, labels):
                 line.extend([f"{v:.2f}" for v in bbox[:4]])
                 line.extend([f"{bbox[4]:.4f}", class_names[label]])
